<?php
    
namespace  Smilepay\Smilepayc2cp\Model;
use Magento\Quote\Model\Quote\Address\RateRequest;
use Magento\Shipping\Model\Carrier\AbstractCarrier;
use Magento\Shipping\Model\Carrier\CarrierInterface;
use Magento\Shipping\Model\Rate\Result;


class Shippingmethod
extends \Magento\Shipping\Model\Carrier\AbstractCarrier
implements \Magento\Shipping\Model\Carrier\CarrierInterface
{
  protected $_code = 'smilepayc2cp';
  protected $emap_url = 'https://emap.presco.com.tw/c2cemap.ashx';
  protected $_isFixed = true;

   
  protected $_rateResultFactory;

  protected $_rateMethodFactory;
  protected $_storeManager;
  protected $_urlInterface;
  protected  $_smilepayc2cp_session;

  public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Quote\Model\Quote\Address\RateResult\ErrorFactory $rateErrorFactory,
        \Psr\Log\LoggerInterface $logger,
        \Magento\Shipping\Model\Rate\ResultFactory $rateResultFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Framework\UrlInterface $urlInterface,
        \Magento\Quote\Model\Quote\Address\RateResult\MethodFactory $rateMethodFactory,
        \Smilepay\Smilepayc2cp\Model\Session $smilepayc2cp_session,
        array $data = []
    ) {
        $this->_rateResultFactory = $rateResultFactory;
        $this->_rateMethodFactory = $rateMethodFactory;
        $this->_storeManager=$storeManager;
        $this->_urlInterface = $urlInterface;
        $this->_smilepayc2cp_session = $smilepayc2cp_session;

        //map mobile start
        $useragent=$_SERVER['HTTP_USER_AGENT'];
        if( strpos( $useragent,'Android') === false && strpos($useragent,'iPad' ) === false && strpos( $useragent,'iPhone') === false
	        || strpos( $useragent,'Safari') === false && strpos( $useragent,'AppleWebKit') === false  && strpos( $useragent,'Dalvik') === false )
        {
            //pc
            $this->emap_url = "https://emap.presco.com.tw/c2cemap.ashx";
        }
        else
        {
            $this->emap_url = "https://emap.presco.com.tw/c2cemapm-u.ashx";
        }
        //map mobile end

        parent::__construct($scopeConfig, $rateErrorFactory, $logger, $data);

   }


  public function getMaxOrderTotal()
  {
    return $this->getConfigData('max_order_total');
  }
  public function getMinOrderTotal()
  {
    return $this->getConfigData('min_order_total');
  }

  public function getCurrencyLimit()
  {
    return trim($this->getConfigData('smilepay_c2cp_currency_limit'));
  }

  public function isActive()
  {
    $result=parent::isActive();
    if( $result)
    {
        if($this->getCurrencyLimit()==true)
        {
            if(  $this->_storeManager->getStore()->getCurrentCurrencyCode() != 'TWD')
                return false;
        }

    }
    return $result;
  }
  public function collectRates(RateRequest $request)
  {
    if (!$this->isActive()) 
    {
            return false;
    }
    //check total
    $total = $request->getBaseSubtotalInclTax()+$this->getConfigData('price');
    $minTotal = $this->getConfigData('min_order_total');
    $maxTotal = $this->getConfigData('max_order_total');
    if ((!empty($minTotal) && ($total < $minTotal)) || (!empty($maxTotal) && ($total > $maxTotal))) {
            return false;
        }


    $result = $this->_rateResultFactory->create();
    $result->append($this->_getDefaultRate($request));
 
    return $result;
  }
 
  public function getAllowedMethods()
  {
    return array(
      'smilepayc2cp' => $this->getConfigData('name'),
     
    );
  }
 
  protected function _getDefaultRate(RateRequest $request)
  {
    $rate =$this->_rateMethodFactory->create();
     
    $rate->setCarrier($this->_code);
    $rate->setCarrierTitle($this->getConfigData('title'));
    $rate->setMethod($this->_code);
    $rate->setMethodTitle($this->getConfigData('name'));
    $rate->setPrice($this->getConfigData('price'));
    $rate->setCost(0);

    //free cost over specfic total
    if ($request->getFreeShipping() 
            ||( $this->getConfigData('free_shipping_enable') == 1  
            && !is_null( $this->getConfigData('free_shipping_subtotal'))
            && !empty($this->getConfigData('free_shipping_subtotal'))
            && $request->getBaseSubtotalInclTax() >= $this->getConfigData('free_shipping_subtotal'))
       )
    {
        $rate->setCost(0);
        $rate->setPrice(0.00);
    }
    return $rate;
  }





  public function getC2CpStoreData()
  {
      $session=$this->_smilepayc2cp_session;

      return $session->getSmilepayc2cpMapResult();

  }
  public function getC2CpStoreAddress()
  {
     
      $result = $this->getC2CpStoreData();
      return  $result['Storeaddress'];
  }
  public function getC2CpStoreId()
  {
      $result = $this->getC2CpStoreData();
      return  $result['Storeid'];
  }
  public function getC2CpStoreName()
  {
      $result = $this->getC2CpStoreData();
      return  $result['Storename'];
  }
  //E-Map selected
  public function isEmapSelected()
  {
      $result = $this->getC2CpStoreData();
      $selected = true;

      if(!isset($result) || empty($result))
        $selected = false;
      else
      {
          foreach($result as $storeData)
          {
            if(!isset($storeData) || empty( $storeData))
            {
              $selected = false;
              break;
            }
          }
      }

      return  $selected;
  }
    // E-Map URL
  public function getEMapUrl()
  {
    return $this->emap_url."?type=eshopid=870&servicetype=1&url=".$this->_urlInterface->getBaseUrl()."smilepayc2cp/emap/saveEmap";
  }





}
?>