<?php

namespace  Smilepay\Smilepayc2cp\Model;

use Magento\Checkout\Model\ConfigProviderInterface;
use Magento\Framework\Escaper;
use Magento\Payment\Helper\Data as PaymentHelper;
use Magento\Framework\View\LayoutInterface;

class Smilepayc2cpConfigProvider implements ConfigProviderInterface
{
    /**
     * @var string[]
     */
    protected $methodCodes =[ \Smilepay\Smilepayc2cp\Model\Paymentmethod::PAYMENT_METHOD_SMILEPAYC2CP_CODE];

    /**
     * @var \Magento\Payment\Model\Method\AbstractMethod[]
     */
    protected $methods = [];

    /**
     * @var Escaper
     */
    protected $escaper;

    protected $_smilepayc2cp_shipping_method;
    protected $_layout;
    /**
     * @param PaymentHelper $paymentHelper
     * @param Escaper $escaper
     */
    public function __construct(
        PaymentHelper $paymentHelper,
        \Smilepay\Smilepayc2cp\Model\Shippingmethod $smilepayc2cp_shipping_method,
        LayoutInterface $layout,
        Escaper $escaper
    ) {
        $this->escaper = $escaper;
        foreach ($this->methodCodes as $code) {
            $this->methods[$code] = $paymentHelper->getMethodInstance($code);
        }
       
        $this->_smilepayc2cp_shipping_method = $smilepayc2cp_shipping_method;
        $this->_layout = $layout;
    }

    /**
     * {@inheritdoc}
     */
    public function getConfig()
    {
        $config = [];
        foreach ($this->methodCodes as $code) {
            if ($this->methods[$code]->isAvailable()) {
                $config['payment']['instructions'][$code] = $this->getInstructions($code);
            }
        }

        $config['shipping']['block']['smilepayc2cp'] = $this->getShippingBlock();

        $c2cdata= $this->getC2CDATA();


        foreach( $c2cdata as $key=>$val)
        {
            $config['shipping']['data']['smilepayc2cp'][$key]= $val; 
        }
    

        return $config;
    }

    /**
     * Get instructions text from config
     *
     * @param string $code
     * @return string
     */
    protected function getInstructions($code)
    {
        return nl2br($this->escaper->escapeHtml($this->methods[$code]->getInstructions()));
    }

    protected function getC2CDATA()
    {
        if($this->_smilepayc2cp_shipping_method->isEmapSelected())
        {
            return array(
                        'storeId' =>$this->_smilepayc2cp_shipping_method->getC2CpStoreId(),
                        'storeName' =>$this->_smilepayc2cp_shipping_method->getC2CpStoreName(),
                        'storeAddr' =>$this->_smilepayc2cp_shipping_method->getC2CpStoreAddress(), 
                        'selected' => true,
                    );
        }
        else    
            return array( 'selected' => false);
        return NULL;
    }

    protected function getShippingBlock()
    {
          

        $block=$this->_layout->createBlock('Smilepay\Smilepayc2cp\Block\Checkout\Shipping\Emap');

        return  $block->toHtml();
    }
}

?>